gcode-documentation-parser
==

See a [demo] usage of the output

A utility that parses the documentation pages from Marlin, RepRap, and Klipper,
to generate an index of commands usage.

Normally, the output would be used by something like [gcode-documentation], to
allow users to search and understand how a GCode command should be used.

This was originally created in [Octoprint] plugin [MarlinGcodeDocumentation],
and needs the parsed documentation data to function.

[demo]:https://costas-basdekis.github.io/gcode-documentation
[gcode-documentation]:https://github.com/costas-basdekis/gcode-documentation
[Octoprint]:https://octoprint.org/
[MarlinGcodeDocumentation]:https://plugins.octoprint.org/plugins/marlingcodedocumentation/

![](https://raw.githubusercontent.com/costas-basdekis/gcode-documentation-parser/main/docs/marlin-gcode-documentation.png)
